***************************
Pipeline (`skypy.pipeline`)
***************************

.. currentmodule:: skypy.pipeline


Running SkyPy
=============

The Pipeline package contains the functionality to run a SkyPy simulation from
end to end. This is implemented in `~driver.SkyPyDriver`.


Reference/API
=============

.. automodapi:: skypy.pipeline
.. automodapi:: skypy.pipeline.driver
